{ config, pkgs, lib, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ./programs.nix
      ./system.nix
      ./acme.nix
      ./networking.nix
      ./nextcloud.nix
      ./minecraft.nix
      ./nur.nix
      # ./factorio.nix # TODO
      ./nginx.nix
      ./cryptpad.nix
      ./hedgedoc.nix
      ./secrets
      # TODO monitoring
    ];

  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "minecraft-server"
    "factorio-headless"
  ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  time.timeZone = "Europe/Paris";

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "us";
  };

  programs.mtr.enable = true;
  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  # Enable the OpenSSH daemon.
  services.openssh.enable = true;
  users.users.root.openssh.authorizedKeys.keyFiles = [
    ./pubkeys/gdd.keys
    ./pubkeys/raito.keys
    ./pubkeys/mrf.keys
  ];

  system.stateVersion = "21.05";
}
